@@ -1,3 +1,12 @@
+"""
+-----Crypte-----
+GitHub : https://github.com/mbcraft-exe/Crypte
+PyPi : https://pypi.org/project/Crypte/
+
+© MB INC
+"""
+
+
 import random
 Keys = ["\n", "a", "z", "e", "r", "t", "y", "u", "i", "o", "p", "q", "s", "²",  "d", "f", "g", "h", "j", "k", "l", "m", "w", "x", "c", "v", "b", "n", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0", "é", "à", "è", " ", "A", "Z", "E", "R", "T", "Y", "U", "I", "O", "P", "Q", "S", "D", "F", "G", "H", "J", "K", "L", "M", "W", "X", "C", "V", "B", "N", "?", ",", ";", ".", ":", "/", "!", ")", "(", "^", "'", "+", "-", "=", "[", "]", "{", "}", "ê", "¨", "@", "-", ",", "/", "'", "<", ">", "_", "-", "~", "#", "|", "ç", "*", "&", "°"]
 CK = Keys
@@ -30,10 +39,15 @@ def decrypte_with_key(msg, key):
     return New_Message
 
 
-def crypte_with_key(msg, key):
+def crypte_with_key(msg, key=False):
     Keys = []
 
-    for k in key:
+    if key == False:
+        K = debug_create_key()
+    else:
+        K = key
+
+    for k in K:
         Keys.append(k)
 
     New_Message = ""
@@ -45,7 +59,10 @@ def crypte_with_key(msg, key):
         except Exception as e:
             New_Message = str(New_Message) + "🔶"
 
-    return New_Message
+    if key != False:
+        return New_Message
+    else:
+        return New_Message + "\n" + K
 
 
 def create_key():
@@ -56,11 +73,25 @@ def create_key():
     for loop in range(int(len(Keys))):
         rdm = random.choice(Keys)
         Keys.remove(rdm)
-        Final_key = Final_key + rdm
+        if rdm != "\n":
+            Final_key = Final_key + rdm
     
     return "\33[37mClé \33[33m" + Final_key + "\33[37m crée."
 
 
+def debug_create_key():
+    Keys = CK
+
+    Final_key = ""
+
+    for loop in range(int(len(Keys))):
+        rdm = random.choice(Keys)
+        Keys.remove(rdm)
+        if rdm != "\n":
+            Final_key = Final_key + rdm
+
+    return Final_key
+
 def decrypte(msg):
     New_Message = ""
 
